VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "clsTaskBarIcon"
Attribute VB_Creatable = False
Attribute VB_Exposed = False
'//**************************** File Information ****************************
'//FileName:      clsTaskbarIcon
'//Version:       3.10
'//Description:   Adds, modifies, or deletes a taskbar icon.
'//Author:        JRB [102251.3060@compuserve.com or XFrench@aol.com]
'//Date Created:  5/29/96
'//Comments:      ***THIS IS A WIN32 CLASS ONLY***
'//*************************************************************************

'//***************************** Default Code ******************************
Option Explicit
Option Base 0
DefInt A-Z

#If Win32 Then
'//******************************* Variables *******************************
'//Structure for the Shell_NotifyIcon function's lpData parameter
Private udtNotify As NOTIFYICONDATA
'//Structure for the SHAppBarMessage function's lpData parameter
Private udtAppBarData As APPBARDATA

'//******************************* Constants *******************************
'//*Identifier of the message to send for the Shell_NotifyIcon function's dwMessage& parameter
Private Const NIM_ADD As Long = 0 '//Adds an icon to the taskbar notification area.
Private Const NIM_DELETE As Long = 2 '//Deletes an icon from the taskbar notification area.
Private Const NIM_MODIFY As Long = 1 '//Changes the icon, tooltip text, or notification message identifier for an icon in the taskbar notification area.

'//*Flags that indicate which of the other structure members in a NOTITFYICONDATA structure are to be processed by the Shell_NofifyIcon function
Private Const NIF_ICON As Long = 2 '//The hIcon member is valid.
Private Const NIF_MESSAGE As Long = 1 '//The uCallbackMessage member is valid.
Private Const NIF_TIP As Long = 4 '//The szTip member is valid.

'//*Identifier of the appbar message to send for the SHAppBarMessage function's dwMessage& parameter
Private Const ABM_GETTASKBARPOS As Long = &H5 '//Retrieves the bounding rectangle of the Windows taskbar.

'//*Base for messages used by private window classes.
Private Const WM_USER As Long = &H400
'//*Default message number that Windows will use to notify the app of mouse events
'//*NOTE: This can be changed.
Private Const DEFAULT_WM_NOTIFYICON As Long = WM_USER + &H301

'//******************************** Types **********************************
'//*Defines the coordinates of the upper-left and lower-right corners of a rectangle.
Private Type RECT
    Left As Long '//Specifies the x-coordinate of the upper-left corner of the rectangle.
    Top As Long '//Specifies the y-coordinate of the upper-left corner of the rectangle.
    Right As Long '//Specifies the x-coordinate of the lower-right corner of the rectangle.
    Bottom As Long '//Specifies the y-coordinate of the lower-right corner of the rectangle.
End Type

'//*Contains information that the system uses to process appbar messages for the SHAppBarMessage function's lpData parameter
Private Type APPBARDATA
    cbSize As Long '//Size of APPBARDATA structure
    hWnd As Long '//handle of appbar
    uCallbackMessage As Long '//Application-defined message identifier.
    uEdge As Long '//Flag that specifies an edge of the screen
    rc As RECT '//RECT structure that contains the bounding rectangle, in screen coordinates, of an appbar or the Windows taskbar
    lParam As Long '//Message-dependent value.
End Type

'//*Contains information that the system needs to process taskbar notification area messages for the Shell_NotifyIcon function's lpData parameter
Private Type NOTIFYICONDATA
    cbSize As Long '//size of NOTIFYICONDATA structure
    hWnd As Long '//Handle of the window that receives notification messages associated with an icon in the taskbar notification area.
    uID As Long '//Application-defined identifier of the taskbar icon.
    uFlags As Long '//Array of flags that indicate which of the other structure members contain valid data.(See the Constansts section for available flags and their purpose.)
    uCallbackMessage As Long '//Application-defined message identifier. The system uses the specified identifier for notification messages that it sends to the window identified by hWnd whenever a mouse event occurs in the bounding rectangle of the icon.
    hIcon As Long '//Handle of the taskbar icon to add, modify, or delete.
    szTip As String * 64 '//Tooltip text to display for the taskbar icon.
End Type
'//******************************* Declares ********************************
'//*Sends a message to the system to add, modify, or delete a taskbar icon.
Private Declare Function Shell_NotifyIcon Lib "shell32.dll" Alias "Shell_NotifyIconA" _
    (ByVal dwMessage&, _
     lpData As NOTIFYICONDATA) _
As Long

'//*Sends an appbar message to the system.
Private Declare Function SHAppBarMessage Lib "shell32.dll" _
    (ByVal dwMessage&, _
     pData As APPBARDATA) _
As Long
 
#End If
 
 
 

'//**************************************************************************
'//Purpose:   Sets the message number that Windows will use to notify
'//           the app of mouse events
'//Inputs:    lngMessage: Application-defined message identifier. The system
'//                   uses the specified identifier for notification messages
'//                   that it sends to the window identified by udtNotify.hWnd whenever
'//                   a mouse event occurs in the bounding rectangle of the icon.
'//Assumes:   udtNofify
'//Returns:   Nothing
'//Effects:   udtNofify.CallbacMessage
'//**************************************************************************
#If Win32 Then
'//Example - clsTaskBar1.CallbackMessage = &H200 '//Assigns a control's MouseMove event
Public Property Let CallbackMessage(lngMessage&)
    
    '//Setup error handling
    On Error Resume Next
    
    udtNotify.uCallbackMessage& = lngMessage&

End Property
#End If
 
 
'//**************************************************************************
'//Purpose:   Assigns a handle of the window that will receive notification messages associated with an icon in the taskbar notification area.
'//Inputs:    lnghWnd: Handle of the window that receives notification messages associated with an icon in the taskbar notification area.
'//Assumes:   udtNotify
'//Returns:   Nothing
'//Effects:   udtNotify.hwnd
'//**************************************************************************
#If Win32 Then
'///Example - clsTaskBar1.hWnd = Form1.hWnd
Public Property Let hWnd(lnghWnd&)
        
    '//Setup error handling
    On Error Resume Next
        
    udtNotify.hWnd& = lnghWnd&

End Property
#End If
 
'//**************************************************************************
'//Purpose:   Gets the message number that Windows will use to notify the
'//               application of mouse events
'//Inputs:    None
'//Assumes:   udtNotify, Default = DEFAULT_WM_NOTIFYICON
'//Returns:   Long - Message indentifier
'//Effects:   Nothing
'//**************************************************************************
#If Win32 Then
'//Example - MsgHook1.Message(clsTaskBar1.CallbackMessage) = True
Public Property Get CallbackMessage() As Long
        
    '//Setup error handling
    On Error Resume Next
        
    CallbackMessage& = udtNotify.uCallbackMessage&

End Property
#End If
 
'//**************************************************************************
'//Purpose:   Adds a new icon to the taskbar notification area
'//Inputs:    lnghIcon -   Handle of the icon to add.
'//           lngIconID -  Application-defined identifier of the taskbar icon.
'//Assumes:   NIF_ICON, NIF_MESSAGE, NIF_TIP,NIM_ADD, udtNotify
'//Returns:   True if successful False otherwise
'//Effects:   udtNotify.uID, udtNotify.hIcon, udtNofity.uFlags
'//**************************************************************************
#If Win32 Then
'//Example - clsTaskBarIcon1.AddIconToTray Form1.Icon, 1
Public Function AddIconToTray(lnghIcon&, lngIconID&) As Boolean
        
    '//Setup error handling
    On Error Resume Next
    
    Dim lRtn&
    
    udtNotify.uID& = lngIconID&
    udtNotify.hIcon& = lnghIcon&
    udtNotify.uFlags& = NIF_ICON& Or NIF_MESSAGE& Or NIF_TIP&
    
    lRtn& = Shell_NotifyIcon&(NIM_ADD&, udtNotify)
    
    If lRtn& Then AddIconToTray = True

End Function
#End If
 
 
'//**************************************************************************
'//Purpose:   Determines if a taskbar exists. If the user is using a 3rd party
'//               shell, it might not.
'//Inputs:    None
'//Assumes:   ABM_GETTASKBARPOS, udtAppBarData
'//Returns:   True if taskbar exists False otherwise
'//Effects:   udtAppBarData.cbSize
'//**************************************************************************
#If Win32 Then
'//Example - If clsTaskBar1.TaskbarExists Then MsgBox "Taskbar present."
Public Function TaskbarExists() As Boolean
    
    '//Setup error handling
    On Error Resume Next
    
    Dim lRtn As Long
    
    udtAppBarData.cbSize& = Len(udtAppBarData) '//36&
    
    lRtn& = SHAppBarMessage&(ABM_GETTASKBARPOS&, udtAppBarData)

    If lRtn& Then TaskbarExists = True

End Function
#End If

'//**************************************************************************
'//Purpose:   Changes the text displayed when the user pauses the mouse over the icon.
'//Inputs:    strNewTip: Tooltip text to display for the taskbar icon.
'//                           Note: Will be truncated if longer than 63 characters
'//           lngID:      Application-defined identifier of the taskbar icon.
'//Assumes:   NIF_TIP, NIM_MODIFY, udtNotify
'//Returns:   True if successful False otherwise
'//Effects:   udtNofify.szTip, udtNotify.uID, udtNotify.uFlags
'//**************************************************************************
#If Win32 Then
'//Example - clsTaskBar1.ChangeTip "My apps name is...", 1
Public Function ChangeTip(strNewTip$, lngIconID&) As Boolean

    '//Setup error handling
    On Error Resume Next
    
    Dim lRtn&
    
    '//Verify that strNewTip is not greater than 63 characters and truncate it if it is.
    If Len(strNewTip$) > 63 Then
        strNewTip$ = Mid$(strNewTip$, 1, 63)
    ElseIf Right$(strNewTip$, 1) <> vbNullChar Then
        strNewTip$ = strNewTip$ & vbNullChar
    End If
    
    '//Put strNewTip$ into the szTip$ element
    udtNotify.szTip = strNewTip$
    
    udtNotify.uID = lngIconID&
    udtNotify.uFlags = NIF_TIP
    
    lRtn& = Shell_NotifyIcon&(NIM_MODIFY, udtNotify)

    If lRtn& Then ChangeTip = True

End Function
#End If
 
'//**************************************************************************
'//Purpose:   Deletes an applications icon from the taskbar
'//Inputs:    lngIconID:  Application-defined identifier of the taskbar icon.
'//Assumes:   NIM_DELETE, udtNotify
'//Returns:   True if successful False otherwise
'//Effects:   udtNotify.uID
'//**************************************************************************
#If Win32 Then
'//Example - clsTaskBar1.DeleteIcon 1
Public Function DeleteIcon(lngIconID&) As Boolean
    
    '//Setup error handling
    On Error Resume Next
    
    '//Return value of Shell_NofifyIcon function
    Dim lRtn&
    
    udtNotify.uID& = lngIconID&
    
    lRtn& = Shell_NotifyIcon&(NIM_DELETE&, udtNotify)
    
    If lRtn& <> 0 Then DeleteIcon = True
    
End Function
#End If
 

#If Win32 Then
Private Sub Class_Initialize()

    '//Setup error handling
    On Error Resume Next
        
    '//Initialize elements of the data structure
    udtNotify.cbSize = Len(udtNotify)
    udtNotify.uFlags = NIF_ICON Or NIF_MESSAGE Or NIF_TIP
    udtNotify.uCallbackMessage = DEFAULT_WM_NOTIFYICON
    udtNotify.szTip = vbNullChar

End Sub
#End If

